#!/bin/bash

arch=$1
if (`test -z "$arch"`) then
   echo "usage: regressTiVoRefCount.sh arch"
   echo "   where arch == ppc"
   echo "      or arch == x86"
   exit 1
fi

if (`test $arch = ppc`) then
    GCC="/usr/local/gcc-ppc/bin/g++"
elif (`test $arch = x86`) then
    GCC="/usr/local/gcc-x86/bin/g++"
else
   echo "usage: regressTiVoRefCount.sh arch"
   echo "   where arch == ppc"
   echo "      or arch == x86"
   exit 1
fi

SRCDIR=`pwd`
INCDIR=/usr/lib/gcc-lib/i386-redhat-linux/egcs-2.90.29/include
LIBDIR_STDCXX=/usr/lib/
LIBDIR_GCC=/usr/lib/gcc-lib/i386-redhat-linux/2.7.2.3/

COMPILE="$GCC -c -O2 -g -I$SRCDIR -I$INCDIR -L$LIBDIR_STDCXX -L$LIBDIR_GCC -Werror -Wall -Wtivo"
STRIP_PWD="sed s:$PWD/::"

# some errors come only from the pcc compiler.  rather than have two
# different gold files, i'm just grepping them out.
FILTER="egrep -v might.be.clobbered.by..longjmp..or..vfork|In.function...static.initializers.for"

someFailed=0
failures=""

for file in `ls $SRCDIR/*.cxx`; do
    echo 
    echo 
    echo '** compiling ' $file
    echo 
    echo $COMPILE $file '2>&1 | tee $file.out'
    echo "$COMPILE $file 2>&1 | $STRIP_PWD | $FILTER | tee $file.out > /dev/null"

    if test -e $file.graph.gold
    then
	export TIVO_CALL_GRAPH=$file.graph
    else
	unset TIVO_CALL_GRAPH
    fi

    $COMPILE $file 2>&1 | $STRIP_PWD | $FILTER | tee $file.out > /dev/null

    diff $file.out.gold $file.out
    outputDiff=$?

    if test -e $file.graph.gold
    then
	diff $file.graph $file.graph.gold
	graphDiff=$?
    else
	graphDiff=0
    fi

    if test $outputDiff != 0 -o $graphDiff != 0
    then
	echo
	echo FAILED: $file -- compare $file.out with its goldens
	someFailed=1
	basename=`basename $file`
	failures="$failures      $basename"
    fi
done


echo 
echo 
echo '**********************************'
echo '**'
if test $someFailed != 0
then
    echo '** THERE WERE SOME FAILURES'
    echo "**   " $failures
else
    echo '** succeeded'
fi
echo '**'
echo '**********************************'

